@@ -27,6 +27,7 @@ var (
 	trackDryRunFlag         bool
 	trackNoModifyAttrsFlag  bool
 	trackNoExcludedFlag     bool
+	trackFilenameFlag       bool
 )
 
 func trackCommand(cmd *cobra.Command, args []string) {
@@ -89,7 +90,14 @@ ArgsLoop:
 		}
 
 		// Generate the new / changed attrib line for merging
-		encodedArg := escapeAttrPattern(pattern)
+		var encodedArg string
+		if trackFilenameFlag {
+			encodedArg = escapeGlobCharacters(pattern)
+			pattern = escapeGlobCharacters(pattern)
+		} else {
+			encodedArg = escapeAttrPattern(pattern)
+		}
+
 		lockableArg := ""
 		if trackLockableFlag { // no need to test trackNotLockableFlag, if we got here we're disabling
 			lockableArg = " " + git.LockableAttrib
@@ -290,8 +298,22 @@ var (
 		" ": "[[:space:]]",
 		"#": "\\#",
 	}
+	trackEscapeStrings = []string{"*", "[", "]", "?"}
 )
 
+func escapeGlobCharacters(s string) string {
+	var escaped string = strings.Replace(s, `\`, "/", -1)
+
+	for _, ch := range trackEscapeStrings {
+		escaped = strings.Replace(escaped, ch, fmt.Sprintf("\\%s", ch), -1)
+	}
+
+	for from, to := range trackEscapePatterns {
+		escaped = strings.Replace(escaped, from, to, -1)
+	}
+	return escaped
+}
+
 func escapeAttrPattern(unescaped string) string {
 	var escaped string = strings.Replace(unescaped, `\`, "/", -1)
 
@@ -320,5 +342,6 @@ func init() {
 		cmd.Flags().BoolVarP(&trackDryRunFlag, "dry-run", "d", false, "preview results of running `git lfs track`")
 		cmd.Flags().BoolVarP(&trackNoModifyAttrsFlag, "no-modify-attrs", "", false, "skip modifying .gitattributes file")
 		cmd.Flags().BoolVarP(&trackNoExcludedFlag, "no-excluded", "", false, "skip listing excluded paths")
+		cmd.Flags().BoolVarP(&trackFilenameFlag, "filename", "", false, "treat this pattern as a literal filename")
 	})
 }
