@@ -3,10 +3,10 @@
 package tools
 
 import (
-	"bufio"
 	"encoding/hex"
 	"fmt"
 	"io"
+	"io/ioutil"
 	"os"
 	"os/user"
 	"path/filepath"
@@ -239,7 +239,7 @@ func VerifyFileHash(oid, path string) error {
 // FastWalkCallback is the signature for the callback given to FastWalkGitRepo()
 type FastWalkCallback func(parentDir string, info os.FileInfo, err error)
 
-// FastWalkGitRepo is a more optimal implementation of filepath.Walk for a Git
+// FastWalkDir is a more optimal implementation of filepath.Walk for a Git
 // repo. The callback guaranteed to be called sequentially. The function returns
 // once all files and errors have triggered callbacks.
 // It differs in the following ways:
@@ -248,18 +248,10 @@ type FastWalkCallback func(parentDir string, info os.FileInfo, err error)
 //    there are no other guarantees. Use parentDir argument in the callback to
 //    determine absolute path rather than tracking it yourself
 //  * Automatically ignores any .git directories
-//  * Respects .gitignore contents and skips ignored files/dirs
 //
 // rootDir - Absolute path to the top of the repository working directory
-func FastWalkGitRepo(rootDir string, cb FastWalkCallback) {
-	fastWalkCallback(fastWalkWithExcludeFiles(rootDir, ".gitignore"), cb)
-}
-
-// FastWalkGitRepoAll behaves as FastWalkGitRepo, with the additional caveat
-// that it does not ignore paths and directories found in .gitignore file(s)
-// throughout the repository.
-func FastWalkGitRepoAll(rootDir string, cb FastWalkCallback) {
-	fastWalkCallback(fastWalkWithExcludeFiles(rootDir, ""), cb)
+func FastWalkDir(rootDir string, cb FastWalkCallback) {
+	fastWalkCallback(fastWalkWithExcludeFiles(rootDir), cb)
 }
 
 // fastWalkCallback calls the FastWalkCallback "cb" for all files found by the
@@ -280,20 +272,18 @@ type fastWalkInfo struct {
 }
 
 type fastWalker struct {
-	rootDir         string
-	excludeFilename string
-	ch              chan fastWalkInfo
-	limit           int32
-	cur             *int32
-	wg              *sync.WaitGroup
+	rootDir string
+	ch      chan fastWalkInfo
+	limit   int32
+	cur     *int32
+	wg      *sync.WaitGroup
 }
 
 // fastWalkWithExcludeFiles walks the contents of a dir, respecting
-// include/exclude patterns and also loading new exlude patterns from files
-// named excludeFilename in directories walked
+// include/exclude patterns.
 //
 // rootDir - Absolute path to the top of the repository working directory
-func fastWalkWithExcludeFiles(rootDir, excludeFilename string) *fastWalker {
+func fastWalkWithExcludeFiles(rootDir string) *fastWalker {
 	excludePaths := []filepathfilter.Pattern{
 		filepathfilter.NewPattern(".git"),
 		filepathfilter.NewPattern("**/.git"),
@@ -306,12 +296,11 @@ func fastWalkWithExcludeFiles(rootDir, excludeFilename string) *fastWalker {
 
 	c := int32(0)
 	w := &fastWalker{
-		rootDir:         rootDir,
-		excludeFilename: excludeFilename,
-		limit:           int32(limit),
-		cur:             &c,
-		ch:              make(chan fastWalkInfo, 256),
-		wg:              &sync.WaitGroup{},
+		rootDir: rootDir,
+		limit:   int32(limit),
+		cur:     &c,
+		ch:      make(chan fastWalkInfo, 256),
+		wg:      &sync.WaitGroup{},
 	}
 
 	go func() {
@@ -327,12 +316,9 @@ func fastWalkWithExcludeFiles(rootDir, excludeFilename string) *fastWalker {
 	return w
 }
 
-// Walk is the main recursive implementation of fast walk.
-// Sends the file/dir and any contents to the channel so long as it passes the
-// include/exclude filter. If a dir, parses any excludeFilename found and updates
-// the excludePaths with its content before (parallel) recursing into contents
-// Also splits large directories into multiple goroutines.
-// Increments waitg.Add(1) for each new goroutine launched internally
+// Walk is the main recursive implementation of fast walk.  Sends the file/dir
+// and any contents to the channel so long as it passes the include/exclude
+// filter.  Increments waitg.Add(1) for each new goroutine launched internally
 //
 // workDir - Relative path inside the repository
 func (w *fastWalker) Walk(isRoot bool, workDir string, itemFi os.FileInfo,
@@ -373,15 +359,6 @@ func (w *fastWalker) Walk(isRoot bool, workDir string, itemFi os.FileInfo,
 		childWorkDir = join(workDir, itemFi.Name())
 	}
 
-	if len(w.excludeFilename) > 0 {
-		possibleExcludeFile := join(fullPath, w.excludeFilename)
-		var err error
-		excludePaths, err = loadExcludeFilename(possibleExcludeFile, childWorkDir, excludePaths)
-		if err != nil {
-			w.ch <- fastWalkInfo{Err: err}
-		}
-	}
-
 	// The absolute optimal way to scan would be File.Readdirnames but we
 	// still need the Stat() to know whether something is a dir, so use
 	// File.Readdir instead. Means we can provide os.FileInfo to callers like
@@ -430,51 +407,6 @@ func (w *fastWalker) Wait() {
 	close(w.ch)
 }
 
-// loadExcludeFilename reads the given file in gitignore format and returns a
-// revised array of exclude paths if there are any changes.
-// If any changes are made a copy of the array is taken so the original is not
-// modified
-func loadExcludeFilename(filename, workDir string, excludePaths []filepathfilter.Pattern) ([]filepathfilter.Pattern, error) {
-	f, err := os.OpenFile(filename, os.O_RDONLY, 0644)
-	if err != nil {
-		if os.IsNotExist(err) {
-			return excludePaths, nil
-		}
-		return excludePaths, err
-	}
-	defer f.Close()
-
-	retPaths := excludePaths
-	modified := false
-
-	scanner := bufio.NewScanner(f)
-	for scanner.Scan() {
-		line := strings.TrimSpace(scanner.Text())
-		// Skip blanks, comments and negations (not supported right now)
-		if len(line) == 0 || strings.HasPrefix(line, "#") || strings.HasPrefix(line, "!") {
-			continue
-		}
-
-		if !modified {
-			// copy on write
-			retPaths = make([]filepathfilter.Pattern, len(excludePaths))
-			copy(retPaths, excludePaths)
-			modified = true
-		}
-
-		path := line
-		// Add pattern in context if exclude has separator, or no wildcard
-		// Allow for both styles of separator at this point
-		if strings.ContainsAny(path, "/\\") ||
-			!strings.Contains(path, "*") {
-			path = join(workDir, line)
-		}
-		retPaths = append(retPaths, filepathfilter.NewPattern(path))
-	}
-
-	return retPaths, nil
-}
-
 func join(paths ...string) string {
 	ne := make([]string, 0, len(paths))
 
@@ -515,6 +447,29 @@ func SetFileWriteFlag(path string, writeEnabled bool) error {
 	return os.Chmod(path, os.FileMode(mode))
 }
 
+// TempFile creates a temporary file in specified directory with proper permissions for the repository.
+// On success, it returns an open, non-nil *os.File, and the caller is responsible
+// for closing and/or removing it.  On failure, the temporary file is
+// automatically cleaned up and an error returned.
+//
+// This function is designed to handle only temporary files that will be renamed
+// into place later somewhere within the Git repository.
+func TempFile(dir, pattern string, cfg repositoryPermissionFetcher) (*os.File, error) {
+	tmp, err := ioutil.TempFile(dir, pattern)
+	if err != nil {
+		return nil, err
+	}
+
+	perms := cfg.RepositoryPermissions(false)
+	err = os.Chmod(tmp.Name(), perms)
+	if err != nil {
+		tmp.Close()
+		os.Remove(tmp.Name())
+		return nil, err
+	}
+	return tmp, nil
+}
+
 // ExecutablePermissions takes a set of Unix permissions (which may or may not
 // have the executable bits set) and maps them into a set of permissions in
 // which the executable bits are set, using the same technique as Git does.
